Function diem_transactional_test_harness::run_test [−][src]
pub fn run_test(path: &Path) -> Result<(), Box<dyn Error>>Expand description
Run the Diem transactional test flow, using the given file as input.
pub fn run_test(path: &Path) -> Result<(), Box<dyn Error>>Run the Diem transactional test flow, using the given file as input.